@@ -46,12 +46,12 @@ class Request(object):
         要自动把endpoint和sn写入
         """
         if isinstance(data, dict):
-            new_data = dict(
-                endpoint=self.endpoint,
-                )
+            new_data = {
+                constants.ENDPOINT_NAME: self.endpoint,
+            }
 
             if self.sn is not None:
-                new_data['sn'] = self.sn
+                new_data[constants.SN_NAME] = self.sn
 
             # 用户传的优先级是最高的，可以覆盖默认的
             new_data.update(data)
