@@ -10,4 +10,4 @@ def safe_call(func, *args, **kwargs):
     try:
         return func(*args, **kwargs)
     except Exception, e:
-        logger.exception('func raise exception. func: %s', func.__name__)
+        logger.exception('func raise exception. func: %s', func)
